@@ -503,15 +503,18 @@ class Hamiltonian():
         my = self.extract(name="my")
         mz = self.extract(name="mz")
         return np.array([mx,my,mz]).T # return array
-    def compute_vev(self,name="sz",**kwargs):
+    def get_vev(self,operator="sz",name=None,**kwargs):
         """
         Compute a VEV of a spatially resolved operator
         """
+        if name is not None: operator=name # overwrite
         n = len(self.geometry.r) # number of sites
         ops = [operators.index(self,n=[i]) for i in range(n)]
-        op = self.get_operator(name) # get an operator
-        ops = [o*op for o in ops] # define operators
+        op = self.get_operator(operator) # get an operator
+        ops = [(o*op).get_matrix() for o in ops] # define operators
         return spectrum.ev(self,operator=ops,**kwargs).real
+    # for backwards compatibility
+    def compute_vev(self,**kwargs): return self.get_vev(**kwargs)
     def get_1dh(self,k=0.0):
         """Return a 1d Hamiltonian"""
         if self.is_multicell: # not implemented
